branch: externals/window-commander
commit dc7f6f264e67ec4d4eeca253078bdd9a9a136e67
Author: Daniel Semyonov <[email protected]>
Commit: Daniel Semyonov <[email protected]>
; Rename files form wincom* to window-commander*
---
wincom.el => window-commander.el | 6 +++---
wincom.texi => window-commander.texi | 0
2 files changed, 3 insertions(+), 3 deletions(-)
diff --git a/wincom.el b/window-commander.el
similarity index 99%
rename from wincom.el
rename to window-commander.el
index defa085530..08b9967495 100644
--- a/wincom.el
+++ b/window-commander.el
@@ -1,4 +1,4 @@
;;; wincom.el --- Simply execute commands on windows -*- lexical-binding: t -*-
lexical-binding: t -*-
;; Copyright (C) 2023 Free Software Foundation, Inc.
@@ -500,6 +500,6 @@ selection:
(remove-hook 'minibuffer-exit-hook #'wincom--update)
(remove-hook 'after-delete-frame-functions #'wincom--update)))
-(provide 'wincom)
+(provide 'window-commander)
-;;; wincom.el ends here
+;;; window-commander.el ends here
@@ -1,4 +1,4 @@
-;;; wincom.el --- Simply execute commands on windows -*- lexical-binding: t -*-
+;;; window-commander.el --- Simply execute commands on windows -*-
lexical-binding: t -*-
;; Copyright (C) 2023 Free Software Foundation, Inc.
diff --git a/wincom.texi b/window-commander.texi
similarity index 100%
rename from wincom.texi
rename to window-commander.texi